@@ -1,108 +1,11 @@
 package Elasticsearch::Bulk;
-{
-  $Elasticsearch::Bulk::VERSION = '0.76';
-}
-
+$Elasticsearch::Bulk::VERSION = '1.00';
 use Moo;
+with 'Elasticsearch::Role::Bulk', 'Elasticsearch::Role::Is_Sync';
 use Elasticsearch::Util qw(parse_params throw);
 use Try::Tiny;
 use namespace::clean;
 
-has 'es'          => ( is => 'ro', required => 1 );
-has 'max_count'   => ( is => 'rw', default  => 1_000 );
-has 'max_size'    => ( is => 'rw', default  => 1_000_000 );
-has 'on_success'  => ( is => 'ro', default  => 0 );
-has 'on_error'    => ( is => 'lazy' );
-has 'on_conflict' => ( is => 'ro', default  => 0 );
-has 'verbose'     => ( is => 'rw' );
-
-has '_buffer' => ( is => 'ro', default => sub { [] } );
-has '_buffer_size'  => ( is => 'rw', default => 0 );
-has '_buffer_count' => ( is => 'rw', default => 0 );
-has '_serializer'   => ( is => 'lazy' );
-has '_bulk_args'    => ( is => 'ro' );
-
-our $Conflict = qr/
-    DocumentAlreadyExistsException
-  | :.version.conflict,.current.\[(\d+)\]
-  /x;
-
-our %Actions = (
-    'index'  => 1,
-    'create' => 1,
-    'update' => 1,
-    'delete' => 1
-);
-
-our @Metadata_Keys = (
-    'index',  'type',      'id',  'routing',
-    'parent', 'timestamp', 'ttl', 'version',
-    'version_type'
-);
-
-#===================================
-sub _build_on_error {
-#===================================
-    my $self       = shift;
-    my $serializer = $self->_serializer;
-    return sub {
-        my ( $action, $result, $src ) = @_;
-        warn( "Bulk error [$action]: " . $serializer->encode($result) );
-    };
-}
-
-#===================================
-sub _build__serializer { shift->es->transport->serializer }
-#===================================
-
-#===================================
-sub BUILDARGS {
-#===================================
-    my ( $class, $params ) = parse_params(@_);
-    my %args;
-    for (qw(index type consistency refresh replication timeout)) {
-        $args{$_} = $params->{$_}
-            if exists $params->{$_};
-    }
-    $params->{_bulk_args} = \%args;
-    return $params;
-}
-
-#===================================
-sub index  { shift->_add( 'index',  @_ ) }
-sub create { shift->_add( 'create', @_ ) }
-sub delete { shift->_add( 'delete', @_ ) }
-sub update { shift->_add( 'update', @_ ) }
-#===================================
-
-#===================================
-sub create_docs {
-#===================================
-    my $self = shift;
-    while ( my $next = shift() ) {
-        $self->add_action( 'create', { _source => $next } );
-    }
-    1;
-}
-
-#===================================
-sub delete_ids {
-#===================================
-    my $self = shift;
-    $self->delete( map { { _id => $_ } } @_ );
-}
-
-#===================================
-sub _add {
-#===================================
-    my $self   = shift;
-    my $action = shift;
-    while ( my $next = shift() ) {
-        $self->add_action( $action, $next );
-    }
-    1;
-}
-
 #===================================
 sub add_action {
 #===================================
@@ -112,15 +15,8 @@ sub add_action {
     my $max_count = $self->max_count;
 
     while (@_) {
-        my $action = shift || '';
-        throw( 'Param', "Unrecognised action <$action>" )
-            unless $Actions{$action};
+        my @json = $self->_encode_action( splice( @_, 0, 2 ) );
 
-        my $params = shift;
-        throw( 'Param', "Missing <params> for action <$action>" )
-            unless ref($params) eq 'HASH';
-
-        my @json = $self->_encode_action( $action, $params );
         push @$buffer, @json;
 
         my $size = $self->_buffer_size;
@@ -136,55 +32,6 @@ sub add_action {
     return 1;
 }
 
-#===================================
-sub _encode_action {
-#===================================
-    my ( $self, $action, $orig ) = @_;
-    my %metadata;
-    my $params     = {%$orig};
-    my $serializer = $self->_serializer;
-
-    for (@Metadata_Keys) {
-        my $val
-            = exists $params->{$_}    ? delete $params->{$_}
-            : exists $params->{"_$_"} ? delete $params->{"_$_"}
-            :                           next;
-        $metadata{"_$_"} = $val;
-    }
-
-    throw( 'Param', "Missing required param <index>" )
-        unless $metadata{_index} || $self->_bulk_args->{index};
-    throw( 'Param', "Missing required param <type>" )
-        unless $metadata{_type} || $self->_bulk_args->{type};
-
-    my $source;
-    if ( $action eq 'update' ) {
-        for (qw(doc upsert doc_as_upsert script params lang)) {
-            $source->{$_} = delete $params->{$_}
-                if exists $params->{$_};
-        }
-    }
-    elsif ( $action ne 'delete' ) {
-        $source
-            = delete $params->{_source}
-            || delete $params->{source}
-            || throw(
-            'Param',
-            "Missing <source> for action <$action>: "
-                . $serializer->encode($orig)
-            );
-    }
-
-    throw(    "Unknown params <"
-            . ( join ',', sort keys %$params )
-            . "> in <$action>: "
-            . $serializer->encode($orig) )
-        if keys %$params;
-
-    return map { $serializer->encode($_) }
-        grep {$_} ( { $action => \%metadata }, $source );
-}
-
 #===================================
 sub flush {
 #===================================
@@ -197,8 +44,9 @@ sub flush {
         local $| = 1;
         print ".";
     }
+    my $buffer  = $self->_buffer;
     my $results = try {
-        $self->es->bulk( %{ $self->_bulk_args }, body => $self->_buffer );
+        $self->es->bulk( %{ $self->_bulk_args }, body => $buffer );
     }
     catch {
         my $error = $_;
@@ -209,32 +57,21 @@ sub flush {
         die $error;
     };
     $self->clear_buffer;
-    $self->_report($results);
+    $self->_report( $buffer, $results );
     return defined wantarray ? $results : undef;
 }
 
-#===================================
-sub clear_buffer {
-#===================================
-    my $self = shift;
-    @{ $self->_buffer } = ();
-    $self->_buffer_size(0);
-    $self->_buffer_count(0);
-}
-
 #===================================
 sub reindex {
 #===================================
     my ( $self, $params ) = parse_params(@_);
     my $src = $params->{source}
         or throw( 'Param', "Missing required param <source>" );
-    my $transform    = $params->{transform};
-    my $version_type = $params->{version_type};
+
+    my $transform = $self->_doc_transformer($params);
 
     if ( ref $src eq 'HASH' ) {
-        require Elasticsearch::Scroll;
-
-        my $scroll = Elasticsearch::Scroll->new(
+        my $scroll = $self->es->scroll_helper(
             es          => $self->es,
             search_type => 'scan',
             size        => 500,
@@ -250,81 +87,26 @@ sub reindex {
             if $self->verbose;
     }
 
-    my $bulk_args = $self->_bulk_args;
-    my %allowed = map { $_ => 1, "_$_" => 1 } ( @Metadata_Keys, 'source' );
-    $allowed{fields} = 1;
-    delete @allowed{ 'index', '_index' } if $bulk_args->{index};
-    delete @allowed{ 'type',  '_type' }  if $bulk_args->{type};
-
-    my $cb = sub {
-        my %doc = %{ shift() };
-        for ( keys %doc ) {
-            delete $doc{$_} unless $allowed{$_};
-        }
-
-        if ( my $fields = delete $doc{fields} ) {
-            for (qw(_routing routing _parent parent)) {
-                $doc{$_} = $fields->{$_}
-                    if exists $fields->{$_};
-            }
-        }
-        $doc{_version_type} = $version_type if $version_type;
-
-        return \%doc unless $transform;
-        return $transform->( \%doc );
-    };
-
     while ( my @docs = $src->() ) {
-        for my $doc (@docs) {
-            $doc = $cb->($doc) or next;
-            $self->index($doc);
-        }
+        $self->index( grep {$_} map { $transform->($_) } @docs );
     }
     $self->flush;
     return 1;
 }
 
-#===================================
-sub _report {
-#===================================
-    my ( $self, $results ) = @_;
-    my $on_success  = $self->on_success;
-    my $on_error    = $self->on_error;
-    my $on_conflict = $self->on_conflict;
-
-    return unless $on_success || $on_error || $on_conflict;
-
-    my $buffer     = $self->_buffer;
-    my $serializer = $self->_serializer;
-
-    my $j = 0;
-
-    for my $item ( @{ $results->{items} } ) {
-        my ( $action, $result ) = %$item;
-        my @args = ($action);
-        if ( my $error = $result->{error} ) {
-            $on_conflict && $error =~ /$Conflict/
-                ? $on_conflict->( $action, $result, $j, $1 )
-                : $on_error && $on_error->( $action, $result, $j );
-        }
-        else {
-            $on_success && $on_success->( $action, $result, $j );
-        }
-        $j++;
-    }
-}
-
 1;
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Elasticsearch::Bulk - A helper module for the Bulk API and for reindexing
 
 =head1 VERSION
 
-version 0.76
+version 1.00
 
 =head1 SYNOPSIS
 
@@ -382,6 +164,9 @@ body, at which point it issues a C<bulk()> request.
 Once you have finished adding actions, call L</flush()> to force the final
 C<bulk()> request on the items left in the queue.
 
+This class does L<Elasticsearch::Role::Bulk> and
+L<Elasticsearch::Role::Is_Sync>.
+
 =head1 CREATING A NEW INSTANCE
 
 =head2 C<new()>
@@ -512,7 +297,7 @@ response.
 
 =head3 C<on_conflict>
 
-    $bulk = Elasticsearch->new(
+    $bulk = Elasticsearch::Bulk->new(
         es           => $es,
         on_conflict  => sub {
             my ($action,$response,$i,$version) = @_;
@@ -527,7 +312,7 @@ of the document currently stored in Elasticsearch (if found).
 
 =head3 C<on_error>
 
-    $bulk = Elasticsearch->new(
+    $bulk = Elasticsearch::Bulk->new(
         es        => $es,
         on_error  => sub {
             my ($action,$response,$i) = @_;
@@ -544,7 +329,7 @@ If you want to be in control of flushing, and you just want to receive
 the raw response that Elasticsearch sends instead of using callbacks,
 then you can do so as follows:
 
-    $bulk = Elasticsearch->new(
+    $bulk = Elasticsearch::Bulk->new(
         es          => $es,
         max_count   => 0,
         max_size    => 0,
@@ -813,7 +598,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Elasticsearch BV.
+This software is Copyright (c) 2014 by Elasticsearch BV.
 
 This is free software, licensed under:
 
