@@ -1,8 +1,5 @@
 package Elasticsearch::Cxn::Factory;
-{
-  $Elasticsearch::Cxn::Factory::VERSION = '0.76';
-}
-
+$Elasticsearch::Cxn::Factory::VERSION = '1.00';
 use Moo;
 use Elasticsearch::Util qw(parse_params load_plugin);
 use namespace::clean;
@@ -19,7 +16,7 @@ sub BUILDARGS {
     my %args = (%$params);
     delete $args{nodes};
 
-    my $cxn_class = load_plugin( 'Cxn', delete $args{cxn} );
+    my $cxn_class = load_plugin( 'Elasticsearch::Cxn', delete $args{cxn} );
     $params->{_factory} = sub {
         my ( $self, $node ) = @_;
         $cxn_class->new(
@@ -42,13 +39,15 @@ sub new_cxn { shift->_factory->(@_) }
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Elasticsearch::Cxn::Factory - Used by CxnPools to create new Cxn instances.
 
 =head1 VERSION
 
-version 0.76
+version 1.00
 
 =head1 DESCRIPTION
 
@@ -65,7 +64,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Elasticsearch BV.
+This software is Copyright (c) 2014 by Elasticsearch BV.
 
 This is free software, licensed under:
 
